==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/dbforpostgresql/kotlin/outputs/GetServerResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dbforpostgresql.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * Represents a server.
 * @property administratorLogin The administrator's login name of a server. Can only be specified when the server is being created (and is required for creation).
 * @property authConfig AuthConfig properties of a server.
 * @property availabilityZone availability zone information of the server.
 * @property backup Backup properties of a server.
 * @property dataEncryption Data encryption properties of a server.
 * @property fullyQualifiedDomainName The fully qualified domain name of a server.
 * @property highAvailability High availability properties of a server.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property identity Describes the identity of the application.
 * @property location The geo-location where the resource lives
 * @property maintenanceWindow Maintenance window properties of a server.
 * @property minorVersion The minor version of the server.
 * @property name The name of the resource
 * @property network Network properties of a server. This Network property is required to be passed only in case you want the server to be Private access server.
 * @property replicaCapacity Replicas allowed for a server.
 * @property replicationRole Replication role of the server
 * @property sku The SKU (pricing tier) of the server.
 * @property sourceServerResourceId The source server resource ID to restore from. It's required when 'createMode' is 'PointInTimeRestore' or 'GeoRestore' or 'Replica'. This property is returned only for Replica server
 * @property state A state of a server that is visible to user.
 * @property storage Storage properties of a server.
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property tags Resource tags.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 * @property version PostgreSQL Server version.
 */
public data class GetServerResult(
    public val administratorLogin: String? = null,
    public val authConfig: AuthConfigResponse? = null,
    public val availabilityZone: String? = null,
    public val backup: BackupResponse? = null,
    public val dataEncryption: DataEncryptionResponse? = null,
    public val fullyQualifiedDomainName: String,
    public val highAvailability: HighAvailabilityResponse? = null,
    public val id: String,
    public val identity: UserAssignedIdentityResponse? = null,
    public val location: String,
    public val maintenanceWindow: MaintenanceWindowResponse? = null,
    public val minorVersion: String,
    public val name: String,
    public val network: NetworkResponse? = null,
    public val replicaCapacity: Int,
    public val replicationRole: String? = null,
    public val sku: SkuResponse? = null,
    public val sourceServerResourceId: String? = null,
    public val state: String,
    public val storage: StorageResponse? = null,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
    public val version: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.dbforpostgresql.outputs.GetServerResult):
            GetServerResult = GetServerResult(
            administratorLogin = javaType.administratorLogin().map({ args0 -> args0 }).orElse(null),
            authConfig = javaType.authConfig().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.AuthConfigResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            availabilityZone = javaType.availabilityZone().map({ args0 -> args0 }).orElse(null),
            backup = javaType.backup().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.BackupResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            dataEncryption = javaType.dataEncryption().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.DataEncryptionResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            fullyQualifiedDomainName = javaType.fullyQualifiedDomainName(),
            highAvailability = javaType.highAvailability().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.HighAvailabilityResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            id = javaType.id(),
            identity = javaType.identity().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.UserAssignedIdentityResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            location = javaType.location(),
            maintenanceWindow = javaType.maintenanceWindow().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.MaintenanceWindowResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            minorVersion = javaType.minorVersion(),
            name = javaType.name(),
            network = javaType.network().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.NetworkResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            replicaCapacity = javaType.replicaCapacity(),
            replicationRole = javaType.replicationRole().map({ args0 -> args0 }).orElse(null),
            sku = javaType.sku().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.SkuResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            sourceServerResourceId = javaType.sourceServerResourceId().map({ args0 -> args0 }).orElse(null),
            state = javaType.state(),
            storage = javaType.storage().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.StorageResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
            version = javaType.version().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/dbforpostgresql/kotlin/outputs/GetServerResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.dbforpostgresql.kotlin.outputs

import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map

/**
 * Represents a server.
 * @property administratorLogin The administrator's login name of a server. Can only be specified when the server is being created (and is required for creation).
 * @property authConfig AuthConfig properties of a server.
 * @property availabilityZone availability zone information of the server.
 * @property backup Backup properties of a server.
 * @property dataEncryption Data encryption properties of a server.
 * @property fullyQualifiedDomainName The fully qualified domain name of a server.
 * @property highAvailability High availability properties of a server.
 * @property id Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
 * @property identity Describes the identity of the application.
 * @property location The geo-location where the resource lives
 * @property maintenanceWindow Maintenance window properties of a server.
 * @property minorVersion The minor version of the server.
 * @property name The name of the resource
 * @property network Network properties of a server. This Network property is required to be passed only in case you want the server to be Private access server.
 * @property replicaCapacity Replicas allowed for a server.
 * @property replicationRole Replication role of the server
 * @property sku The SKU (pricing tier) of the server.
 * @property sourceServerResourceId The source server resource ID to restore from. It's required when 'createMode' is 'PointInTimeRestore' or 'GeoRestore' or 'Replica'. This property is returned only for Replica server
 * @property state A state of a server that is visible to user.
 * @property storage Storage properties of a server.
 * @property systemData Azure Resource Manager metadata containing createdBy and modifiedBy information.
 * @property tags Resource tags.
 * @property type The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
 * @property version PostgreSQL Server version.
 */
public data class GetServerResult(
    public val administratorLogin: String? = null,
    public val authConfig: AuthConfigResponse? = null,
    public val availabilityZone: String? = null,
    public val backup: BackupResponse? = null,
    public val dataEncryption: DataEncryptionResponse? = null,
    public val fullyQualifiedDomainName: String,
    public val highAvailability: HighAvailabilityResponse? = null,
    public val id: String,
    public val identity: UserAssignedIdentityResponse? = null,
    public val location: String,
    public val maintenanceWindow: MaintenanceWindowResponse? = null,
    public val minorVersion: String,
    public val name: String,
    public val network: NetworkResponse? = null,
    public val replicaCapacity: Int,
    public val replicationRole: String? = null,
    public val sku: SkuResponse? = null,
    public val sourceServerResourceId: String? = null,
    public val state: String,
    public val storage: StorageResponse? = null,
    public val systemData: SystemDataResponse,
    public val tags: Map<String, String>? = null,
    public val type: String,
    public val version: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.dbforpostgresql.outputs.GetServerResult): GetServerResult = GetServerResult(
            administratorLogin = javaType.administratorLogin().map({ args0 -> args0 }).orElse(null),
            authConfig = javaType.authConfig().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.AuthConfigResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            availabilityZone = javaType.availabilityZone().map({ args0 -> args0 }).orElse(null),
            backup = javaType.backup().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.BackupResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            dataEncryption = javaType.dataEncryption().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.DataEncryptionResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            fullyQualifiedDomainName = javaType.fullyQualifiedDomainName(),
            highAvailability = javaType.highAvailability().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.HighAvailabilityResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            id = javaType.id(),
            identity = javaType.identity().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.UserAssignedIdentityResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            location = javaType.location(),
            maintenanceWindow = javaType.maintenanceWindow().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.MaintenanceWindowResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            minorVersion = javaType.minorVersion(),
            name = javaType.name(),
            network = javaType.network().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.NetworkResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            replicaCapacity = javaType.replicaCapacity(),
            replicationRole = javaType.replicationRole().map({ args0 -> args0 }).orElse(null),
            sku = javaType.sku().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.SkuResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            sourceServerResourceId = javaType.sourceServerResourceId().map({ args0 -> args0 }).orElse(null),
            state = javaType.state(),
            storage = javaType.storage().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.StorageResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.dbforpostgresql.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            tags = javaType.tags().map({ args0 -> args0.key.to(args0.value) }).toMap(),
            type = javaType.type(),
            version = javaType.version().map({ args0 -> args0 }).orElse(null),
        )
    }
}
